@@ -106,6 +106,7 @@ class InheritanceQuerySetMixin(object):
             rel for rel in model._meta.get_all_related_objects()
             if isinstance(rel.field, OneToOneField)
             and issubclass(rel.field.model, model)
+            and model is not rel.field.model
             ]
         subclasses = []
         if levels:
@@ -239,6 +240,8 @@ class PassThroughManagerMixin(object):
     def __getattr__(self, name):
         if name in self._deny_methods:
             raise AttributeError(name)
+        if django.VERSION < (1, 6, 0):
+            return getattr(self.get_query_set(), name)
         return getattr(self.get_queryset(), name)
 
     def get_queryset(self):
@@ -281,8 +284,8 @@ class PassThroughManager(PassThroughManagerMixin, models.Manager):
 
 def create_pass_through_manager_for_queryset_class(base, queryset_cls):
     class _PassThroughManager(base):
-        def __init__(self):
-            return super(_PassThroughManager, self).__init__()
+        def __init__(self, *args, **kwargs):
+            return super(_PassThroughManager, self).__init__(*args, **kwargs)
 
         def get_queryset(self):
             qs = super(_PassThroughManager, self).get_queryset()
