@@ -1,20 +1,15 @@
-from datetime import datetime
+from __future__ import unicode_literals
 
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
 from django.db.models.fields import FieldDoesNotExist
 from django.core.exceptions import ImproperlyConfigured
+from django.utils.timezone import now
 
 from model_utils.managers import QueryManager
 from model_utils.fields import AutoCreatedField, AutoLastModifiedField, \
     StatusField, MonitorField
 
-try:
-    from django.utils.timezone import now as now
-except ImportError:
-    now = datetime.now
-
-
 
 class TimeStampedModel(models.Model):
     """
@@ -63,13 +58,13 @@ def add_status_query_managers(sender, **kwargs):
     """
     if not issubclass(sender, StatusModel):
         return
-    for value, name in getattr(sender, 'STATUS', ()):
+    for value, display in getattr(sender, 'STATUS', ()):
         try:
-            sender._meta.get_field(name)
+            sender._meta.get_field(value)
             raise ImproperlyConfigured("StatusModel: Model '%s' has a field "
                                        "named '%s' which conflicts with a "
                                        "status of the same name."
-                                       % (sender.__name__, name))
+                                       % (sender.__name__, value))
         except FieldDoesNotExist:
             pass
         sender.add_to_class(value, QueryManager(status=value))
