@@ -1238,12 +1238,19 @@ class PassThroughManagerTests(TestCase):
 class CreatePassThroughManagerTests(TestCase):
     def setUp(self):
         self.dude = Dude.objects.create(name='El Duderino')
+        self.other_dude = Dude.objects.create(name='Das Dude')
 
     def test_reverse_manager(self):
         Spot.objects.create(
             name='The Crib', owner=self.dude, closed=True, secure=True,
             secret=False)
         self.assertEqual(self.dude.spots_owned.closed().count(), 1)
+        Spot.objects.create(
+            name='The Crux', owner=self.other_dude, closed=True, secure=True,
+            secret=False
+        )
+        self.assertEqual(self.dude.spots_owned.closed().all().count(), 1)
+        self.assertEqual(self.dude.spots_owned.closed().count(), 1)
 
     def test_related_queryset_pickling(self):
         Spot.objects.create(
@@ -1432,6 +1439,24 @@ class FieldTrackerTests(FieldTrackerTestCase, FieldTrackerCommonTests):
         self.assertEqual(in_db.number, self.instance.number)
         self.assertEqual(in_db.mutable, self.instance.mutable)
 
+    def test_with_deferred(self):
+        self.instance.name = 'new age'
+        self.instance.number = 1
+        self.instance.save()
+        item = list(self.tracked_class.objects.only('name').all())[0]
+        self.assertTrue(item.tracker.deferred_fields)
+
+        self.assertEqual(item.tracker.previous('number'), None)
+        self.assertTrue('number' in item.tracker.deferred_fields)
+
+        self.assertEqual(item.number, 1)
+        self.assertTrue('number' not in item.tracker.deferred_fields)
+        self.assertEqual(item.tracker.previous('number'), 1)
+        self.assertFalse(item.tracker.has_changed('number'))
+
+        item.number = 2
+        self.assertTrue(item.tracker.has_changed('number'))
+
 
 class FieldTrackedModelCustomTests(FieldTrackerTestCase,
                                    FieldTrackerCommonTests):
